@@ -43,6 +43,17 @@ export async function POST(request: NextRequest) {
     // Send notification to admin
     await sendAccessRequestNotification(email, company)
 
+    // Discord log
+    const { discord } = await import('@/lib/discord-logger')
+    await discord.studio(
+      'Nouvelle Demande Studio',
+      `**${name}** de **${company}** demande un accès studio.`,
+      [
+        { name: 'Email', value: email, inline: true },
+        { name: 'Entreprise', value: company, inline: true }
+      ]
+    )
+
     return NextResponse.json({
       message: 'Demande envoyée avec succès',
     })
