@@ -24,6 +24,9 @@ export const users = pgTable('users', {
 
   // New Fields
   discordHandle: varchar('discord_handle', { length: 255 }),
+  bio: text('bio'), // Creator bio visible to studios
+  privacyPolicyAccepted: integer('privacy_policy_accepted').default(0), // 0 = no, 1 = yes
+  termsAccepted: integer('terms_accepted').default(0), // 0 = no, 1 = yes
   balance: decimal('balance', { precision: 10, scale: 2 }).default('0').notNull(),
 
   // Social Media OAuth Tokens (kept for app logic, though NextAuth handles accounts separately)
@@ -198,6 +201,19 @@ export const gameKeys = pgTable('game_keys', {
   isClaimedIdx: index('game_keys_is_claimed_idx').on(table.isClaimed),
 }))
 
+// Campaign Resources Table (Drive, Discord, YouTube links)
+export const campaignResources = pgTable('campaign_resources', {
+  id: uuid('id').defaultRandom().primaryKey(),
+  campaignId: uuid('campaign_id').references(() => campaigns.id, { onDelete: 'cascade' }).notNull(),
+  type: varchar('type', { length: 50 }).notNull(), // 'drive', 'discord', 'youtube', 'link'
+  title: varchar('title', { length: 255 }).notNull(),
+  url: varchar('url', { length: 500 }).notNull(),
+  description: text('description'),
+  createdAt: timestamp('created_at').defaultNow().notNull(),
+}, (table) => ({
+  campaignIdIdx: index('campaign_resources_campaign_id_idx').on(table.campaignId),
+}))
+
 // Submissions Table
 export const submissions = pgTable('submissions', {
   id: uuid('id').defaultRandom().primaryKey(),
@@ -214,6 +230,7 @@ export const submissions = pgTable('submissions', {
   submittedAt: timestamp('submitted_at').defaultNow().notNull(),
   reviewedAt: timestamp('reviewed_at'),
   invoiceId: uuid('invoice_id'), // Link to the generated invoice
+  legalCertified: integer('legal_certified').default(0).notNull(), // 1 = creator certified compliance
   createdAt: timestamp('created_at').defaultNow().notNull(),
   updatedAt: timestamp('updated_at').defaultNow().notNull(),
 }, (table) => ({
@@ -246,20 +263,23 @@ export const submissionStatsHistoryRelations = relations(submissionStatsHistory,
 // Invoices Table
 export const invoices = pgTable('invoices', {
   id: uuid('id').defaultRandom().primaryKey(),
-  creatorId: uuid('creator_id').references(() => users.id, { onDelete: 'cascade' }).notNull(),
+  creatorId: uuid('creator_id').references(() => users.id, { onDelete: 'cascade' }), // Optional now
   studioId: uuid('studio_id').references(() => users.id, { onDelete: 'cascade' }).notNull(),
+  campaignId: uuid('campaign_id').references(() => campaigns.id, { onDelete: 'set null' }), // Link to campaign
   amount: decimal('amount', { precision: 10, scale: 2 }).notNull(),
+  currency: varchar('currency', { length: 3 }).default('EUR').notNull(),
   pdfUrl: varchar('pdf_url', { length: 500 }).notNull(),
   invoiceNumber: varchar('invoice_number', { length: 100 }).notNull(),
   periodStart: timestamp('period_start'),
   periodEnd: timestamp('period_end'),
-  status: varchar('status', { length: 20 }).default('pending').notNull(), // 'pending', 'paid', 'failed'
+  status: varchar('status', { length: 20 }).default('pending').notNull(), // 'pending', 'pending_verification', 'paid', 'failed'
   paymentReference: varchar('payment_reference', { length: 255 }),
   paidAt: timestamp('paid_at'),
   createdAt: timestamp('created_at').defaultNow().notNull(),
 }, (table) => ({
   creatorIdIdx: index('invoices_creator_id_idx').on(table.creatorId),
   studioIdIdx: index('invoices_studio_id_idx').on(table.studioId),
+  campaignIdIdx: index('invoices_campaign_id_idx').on(table.campaignId),
 }))
 
 // Campaign Applications Table
@@ -328,6 +348,10 @@ export const invoicesRelations = relations(invoices, ({ one, many }) => ({
     references: [users.id],
     relationName: 'studioInvoices',
   }),
+  campaign: one(campaigns, {
+    fields: [invoices.campaignId],
+    references: [campaigns.id],
+  }),
   submissions: many(submissions),
 }))
 
